@@ -2,8 +2,10 @@ from selenium.webdriver.common.by import By
 
 class setup:
     ''' '''
-    def __init__(self, driver):
+    def __init__(self, driver, wait_for=10):
+        driver.implicitly_wait(wait_for) # Wait X seconds for element to load before raising error
         self.driver = driver
+        self.wait_for = wait_for
         
     def find(self, css_selector, attribute=None, parent=None):
         if not parent:
@@ -14,14 +16,14 @@ class setup:
             return element, attribute
         return element
 
-    def finds(self, css_selector, parent=None, wait=None):
+    def finds(self, css_selector, parent=None, wait_for=None):
         if not parent:
             parent = self.driver
-        if wait:
-            self.driver.implicitly_wait(wait)
+        if wait_for:
+            self.driver.implicitly_wait(wait_for)
         elements = parent.find_elements(By.CSS_SELECTOR, css_selector)
-        if wait:
-            self.driver.implicitly_wait(15)
+        if wait_for:
+            self.driver.implicitly_wait(self.wait_for)
         return elements
 
     def click(self, css_selector, parent=None):
@@ -49,3 +51,11 @@ class setup:
             parent = self.driver
         if parent.current_url != url:
             parent.get(url)
+
+    def check(self, css_selector, parent=None):
+        if not parent:
+            parent = self.driver
+        self.driver.implicitly_wait(1)
+        elements = parent.find_elements(By.CSS_SELECTOR, css_selector)
+        self.driver.implicitly_wait(self.wait_for)
+        return elements
\ No newline at end of file
